train_tools.data_utils.custom.CellAware — spacr 0.5.0 documentation

# train_tools.data_utils.custom.CellAware

## Module Contents

class train_tools.data_utils.custom.CellAware.BoundaryExclusion(keys=['label'], allow_missing_keys=False)

  Bases: `monai.transforms.compose.MapTransform`

  Map the cell boundary pixel labels to the background class (0).

class train_tools.data_utils.custom.CellAware.IntensityDiversification(keys=['img'], change_cell_ratio=0.4, scale_factors=[0, 0.7], allow_missing_keys=False)

  Bases: `monai.transforms.compose.MapTransform`

  Randomly rescale the intensity of cell pixels.

  change_cell_ratio = 0.4
  randscale_intensity